# Emojito

There are many packages that provide shortnames for emojis. This package allows you to provide your own shortnames and with what to replace them.

## Features

- Find and replace shortnames. You provide the shortnames and the content with which to replace them.
- Compatible with HTML. In stead of indiscrimnately finding and replacing shortnames anywhere in the text, accidentally replacing content that overlaps with tags, the HTML will be parsed and only the plain text within tags will be affected.